rwslib
======

The Goal of this library is to provide a (programmer) friendly client library to Rave Web Services (RWS).

Philosophy
----------

rwslib provides a convenient interface to RWS without hiding the implementation details. For instance,
using rwslib you should have a simple way to request a list of studies from RWS but still be able to
get to the HTTP headers, content body etc returned by RWS.

Documentation
-------------

Documented with Sphinx. See http://rwslib.readthedocs.org/en/latest/

